@@ -1,15 +1,26 @@
+# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-License-Identifier: CC0-1.0
+
 """
 A bunch of quick tests that confirm nothing is horribly wrong
 """
 
+from __future__ import annotations
+
 import ast
 import gc
+import sys
 from contextlib import suppress
 from pathlib import Path
 from shutil import copy
 
 import pytest
-import toml
+
+try:
+    import tomllib
+except ModuleNotFoundError:
+    import tomli as tomllib  # type: ignore
+
 from packaging.version import Version
 
 import pikepdf
@@ -19,9 +30,12 @@ from pikepdf import Name, Object, Pdf, Stream
 def test_minimum_qpdf_version():
     from pikepdf import _qpdf
 
-    pyproject_toml = toml.load(Path(__file__).parent / '../pyproject.toml')
+    with open(Path(__file__).parent / '../pyproject.toml', 'rb') as f:
+        pyproject_toml = tomllib.load(f)
     toml_env = pyproject_toml['tool']['cibuildwheel']['environment']
 
+    if sys.platform == 'darwin' and toml_env['QPDF_MIN_VERSION'] == '11.1.0':
+        pytest.xfail("Temporarily disable check for Homebrew's sake")
     assert Version(_qpdf.qpdf_version()) >= Version(toml_env['QPDF_MIN_VERSION'])
 
 
